"""
Tests of :mod:`edx_ace.presentation`.
"""
from unittest import TestCase
from unittest.mock import Mock

from edx_ace.errors import UnsupportedChannelError
from edx_ace.presentation import render


class TestRender(TestCase):
    """
    Tests for unsupported rendering for a channel.
    """

    def test_missing_renderer(self):
        channel = Mock(
            channel_type='unsupported_channel_type'
        )

        message = Mock()

        with self.assertRaises(UnsupportedChannelError):
            render(channel, message)



"""
An internal module that manages the presentation/rendering step of the
ACE pipeline.
"""
from django.utils import translation

from edx_ace import errors, renderers
from edx_ace.channel import ChannelType

RENDERERS = {
    ChannelType.EMAIL: renderers.EmailRenderer(),
    ChannelType.PUSH: renderers.PushNotificationRenderer(),
}


def render(channel, message):
    """ Returns the rendered content for the given channel and message. """
    renderer = RENDERERS.get(channel.channel_type)

    if not renderer:
        error_msg = f'No renderer is registered for the channel type [{channel.channel_type}].'
        raise errors.UnsupportedChannelError(error_msg)

    message_language = message.language or translation.get_language()
    with translation.override(message_language):
        return renderer.render(channel, message)
